]> sigrok.org Git - sigrok-cli.git/commitdiff
sr: Name all callback data 'cb_data'.
authorUwe Hermann <redacted>
Wed, 29 Feb 2012 21:32:34 +0000 (22:32 +0100)
committerUwe Hermann <redacted>
Fri, 2 Mar 2012 01:25:42 +0000 (02:25 +0100)
anykey.c
sigrok-cli.c

index f0ab52efe6548a9654822781670acd4ab80d046d..5bc230bd7b47eccdf268f33c21db416eb5beac8d 100644 (file)
--- a/anykey.c
+++ b/anykey.c
@@ -36,12 +36,12 @@ static DWORD stdin_mode;
 static struct termios term_orig;
 #endif
 
-static int received_anykey(int fd, int revents, void *user_data)
+static int received_anykey(int fd, int revents, void *cb_data)
 {
        /* Avoid compiler warnings. */
        (void)fd;
        (void)revents;
-       (void)user_data;
+       (void)cb_data;
 
        sr_session_stop();
 
index 461899e14f255c6fc0768c7b4a5360ce79f3183c..d5427a785b82e4287799363d09c77be30e07ef7c 100644 (file)
@@ -514,13 +514,13 @@ err_out:
        return 0;
 }
 
-void show_pd_annotation(struct srd_proto_data *pdata, void *user_data)
+void show_pd_annotation(struct srd_proto_data *pdata, void *cb_data)
 {
        int i;
        char **annotations;
 
-       /* 'user_data' is not used in this specific callback. */
-       (void)user_data;
+       /* 'cb_data' is not used in this specific callback. */
+       (void)cb_data;
 
        if (pdata->ann_format != 0) {
                /* CLI only shows the default annotation format. */
@@ -943,11 +943,11 @@ static void run_session(void)
 }
 
 static void logger(const gchar *log_domain, GLogLevelFlags log_level,
-                  const gchar *message, gpointer user_data)
+                  const gchar *message, gpointer cb_data)
 {
        /* Avoid compiler warnings. */
        (void)log_domain;
-       (void)user_data;
+       (void)cb_data;
 
        /*
         * All messages, warnings, errors etc. go to stderr (not stdout) in